@@ -20,7 +20,11 @@ class BloomCriticalThinking(CriticalThinking):
             "1. Analyze: break down into components.\n"
             "2. Evaluate: assess quality, validity, importance.\n"
             "3. Create: propose new synthesis, alternative solutions, or reformulations.\n\n"
-            "Output under headings: Analyze, Evaluate, Create."
+            "Output under headings: Analyze, Evaluate, Create.\n\n"
+            "## Output Constraints\n"
+            "- Do not use '#' for headings, as it is reserved as a system markup tag.\n"
+            "- Use numbered or bullet points.\n"
+            "- Do not include explanations, comments, or extra content."
         )
         return self.llm.request([prompt]).strip()
 
