@@ -22,6 +22,10 @@ class PaulElderCriticalThinking(CriticalThinking):
             "concepts, assumptions, implications, point of view.\n\n"
             "Also evaluate using reasoning standards: clarity, accuracy, precision, relevance, "
             "depth, breadth, logic, fairness.\n\n"
-            "Output your structured assessment clearly under these categories."
+            "Output your structured assessment clearly under these categories.\n\n"
+            "## Output Constraints\n"
+            "- Do not use '#' for headings, as it is reserved as a system markup tag.\n"
+            "- Use numbered or bullet points.\n"
+            "- Do not include explanations, comments, or extra content."
         )
         return self.llm.request([prompt]).strip()
\ No newline at end of file
