@@ -18,7 +18,11 @@ class RedTeamCriticalThinking(CriticalThinking):
             "1. Identify assumptions and potential biases.\n"
             "2. Challenge the reasoning with counterarguments.\n"
             "3. Suggest ways to improve robustness.\n\n"
-            "Output under headings: Assumptions, Counterarguments, Improvements."
+            "Output under headings: Assumptions, Counterarguments, Improvements.\n\n"
+            "## Output Constraints\n"
+            "- Do not use '#' for headings, as it is reserved as a system markup tag.\n"
+            "- Use numbered or bullet points.\n"
+            "- Do not include explanations, comments, or extra content."
         )
         return self.llm.request([prompt]).strip()
 
