@@ -20,6 +20,10 @@ class ReflectiveEquilibriumCriticalThinking(CriticalThinking):
             "2. Compare them with general principles.\n"
             "3. Introduce counterexamples or alternative views.\n"
             "4. Adjust until coherence is reached.\n\n"
-            "Output under headings: Initial Judgments, Principles, Counterexamples, Adjustments, Equilibrium."
+            "Output under headings: Initial Judgments, Principles, Counterexamples, Adjustments, Equilibrium.\n\n"
+            "## Output Constraints\n"
+            "- Do not use '#' for headings, as it is reserved as a system markup tag.\n"
+            "- Use numbered or bullet points.\n"
+            "- Do not include explanations, comments, or extra content."
         )
         return self.llm.request([prompt]).strip()
