@@ -17,6 +17,10 @@ class RootCauseAnalysisCriticalThinking(CriticalThinking):
             "## Process\n"
             "Ask 'Why?' iteratively up to five times to identify the root cause.\n"
             "Output under the following format:\n"
-            "- Why 1:\n- Why 2:\n- Why 3:\n- Why 4:\n- Why 5:\n- Root Cause:"
+            "- Why 1:\n- Why 2:\n- Why 3:\n- Why 4:\n- Why 5:\n- Root Cause:\n\n"
+            "## Output Constraints\n"
+            "- Do not use '#' for headings, as it is reserved as a system markup tag.\n"
+            "- Use numbered or bullet points.\n"
+            "- Do not include explanations, comments, or extra content."
         )
         return self.llm.request([prompt]).strip()
\ No newline at end of file
