@@ -22,6 +22,10 @@ class SixThinkingHatsCriticalThinking(CriticalThinking):
             "- Black Hat (risks & problems)\n"
             "- Yellow Hat (benefits & positives)\n"
             "- Green Hat (creativity & alternatives)\n"
-            "- Blue Hat (process & control)"
+            "- Blue Hat (process & control)\n\n"
+            "## Output Constraints\n"
+            "- Do not use '#' for headings, as it is reserved as a system markup tag.\n"
+            "- Use numbered or bullet points.\n"
+            "- Do not include explanations, comments, or extra content."
         )
         return self.llm.request([prompt]).strip()
\ No newline at end of file
