@@ -23,6 +23,10 @@ class SocraticQuestioningCriticalThinking(CriticalThinking):
             "- Viewpoint Exploration\n"
             "- Implication Probes\n"
             "- Questioning the Question\n\n"
-            "Output structured under these headings."
+            "Output structured under these headings.\n\n"
+            "## Output Constraints\n"
+            "- Do not use '#' for headings, as it is reserved as a system markup tag.\n"
+            "- Use numbered or bullet points.\n"
+            "- Do not include explanations, comments, or extra content."
         )
         return self.llm.request([prompt]).strip()
\ No newline at end of file
