@@ -16,6 +16,10 @@ class AccuracyCheck(Evaluation):
             "## Guidelines\n"
             "- Evaluate correctness against known facts, expected results, or gold standards.\n"
             "- Provide a numeric score (0.0-1.0) and a brief rationale.\n"
-            "- Keep the explanation concise and structured."
+            "- Keep the explanation concise and structured.\n\n"
+            "## Output Constraints\n"
+            "- Do not use '#' for headings, as it is reserved as a system markup tag.\n"
+            "- Use numbered or bullet points.\n"
+            "- Do not include explanations, comments, or extra content."
         )
         return self.llm.request([prompt]).strip()
