@@ -15,6 +15,10 @@ class CompletenessCheck(Evaluation):
             f"## Output\n{result}\n\n"
             "## Guidelines\n"
             "- Verify that all expected components or steps are included.\n"
-            "- Indicate 'complete' if all parts are present, otherwise 'incomplete' with brief note of missing elements."
+            "- Indicate 'complete' if all parts are present, otherwise 'incomplete' with brief note of missing elements.\n\n"
+            "## Output Constraints\n"
+            "- Do not use '#' for headings, as it is reserved as a system markup tag.\n"
+            "- Use numbered or bullet points.\n"
+            "- Do not include explanations, comments, or extra content."
         )
         return self.llm.request([prompt]).strip()
