@@ -16,6 +16,10 @@ class ConsistencyCheck(Evaluation):
             "## Guidelines\n"
             "- Check for contradictions or violations of constraints.\n"
             "- Highlight inconsistencies with concise reasoning.\n"
-            "- Output only 'consistent' or 'inconsistent' with a brief rationale."
+            "- Output only 'consistent' or 'inconsistent' with a brief rationale.\n\n"
+            "## Output Constraints\n"
+            "- Do not use '#' for headings, as it is reserved as a system markup tag.\n"
+            "- Use numbered or bullet points.\n"
+            "- Do not include explanations, comments, or extra content."
         )
         return self.llm.request([prompt]).strip()
