@@ -16,6 +16,10 @@ class CriticalReflection(Evaluation):
             "## Guidelines\n"
             "- Consider social, ethical, operational, and strategic implications.\n"
             "- Summarize key insights succinctly.\n"
-            "- Avoid extraneous commentary."
+            "- Avoid extraneous commentary.\n\n"
+            "## Output Constraints\n"
+            "- Do not use '#' for headings, as it is reserved as a system markup tag.\n"
+            "- Use numbered or bullet points.\n"
+            "- Do not include explanations, comments, or extra content."
         )
         return self.llm.request([prompt]).strip()
