@@ -16,6 +16,10 @@ class PeerReview(Evaluation):
             "## Guidelines\n"
             "- Provide structured review feedback.\n"
             "- Highlight strengths and weaknesses.\n"
-            "- Avoid unrelated commentary."
+            "- Avoid unrelated commentary.\n\n"
+            "## Output Constraints\n"
+            "- Do not use '#' for headings, as it is reserved as a system markup tag.\n"
+            "- Use numbered or bullet points.\n"
+            "- Do not include explanations, comments, or extra content."
         )
         return self.llm.request([prompt]).strip()
