@@ -16,6 +16,10 @@ class RedTeamEvaluation(Evaluation):
             "## Guidelines\n"
             "- Identify potential weaknesses, errors, or risky assumptions.\n"
             "- Suggest improvements or note risks succinctly.\n"
-            "- Output as structured critique without extra commentary."
+            "- Output as structured critique without extra commentary.\n\n"
+            "## Output Constraints\n"
+            "- Do not use '#' for headings, as it is reserved as a system markup tag.\n"
+            "- Use numbered or bullet points.\n"
+            "- Do not include explanations, comments, or extra content."
         )
         return self.llm.request([prompt]).strip()
